function pendelMprKonv

%initialisation
N=100:100:1000;
T=10;

%fixed number of newton iterations
nNewton=3;

%energy function (Hamilton function)
H=@(y) 0.5*y(2)^2-cos(y(1));

%initial condition (is used several times)
yStart=[pi/2;0];

%array, which saves the oscillations of the energy
energyoscillation=zeros(size(N));

%for all numbers of steps
for kk=1:length(N)
    
    %set the initial condition
    y=yStart;
    %determine the step size
    h=T/N(kk);
    
    %formulate the root finding procedure
    %(the function depends on h!!)
    f=@(y) [y(2); -sin(y(1))];
    Df=@(y) [0 1; -cos(y(1)) 0];
    F=@(y,y0) y-y0-h*f((y0+y)/2);
    DF=@(y,y0) eye(length(y))-h/2*Df((y0+y)/2);

    
    %array, in which you save the evolution of the energy
    energy=zeros(N(kk)+1,1);
    energy(1)=H(y);
    
    for ii=1:N(kk)
        %perform one step of the implicit midpoint method
        y0=y;
        %with nNewton steps
        for jj=1:nNewton
            y=y-DF(y,y0)\F(y,y0);
            
        end
        %save the energy
        energy(ii+1)=H(y);
    end
    %read the maximum absolute energy oscillation 
    energyoscillation(kk)=max(abs(energy));
end

%loglog plot
figure;
loglog(N,energyoscillation,'*-');

%determine the algebraic convergence
fit=polyfit(log(N),log(energyoscillation),1);
fprintf('order of convergence %2.4f\n', fit(1));