function [t, p, q] = RK4(p0, q0, tspan, h)
% RK4 method for
% 
%  [p',q'] = [p,q]/(p^2 + q^2)
%
% Input paramters:
% p0: initial value for p
% q0: initial value for q
% tspan: [t0, T] starting and stopping time
% h: timestep size
%
% Outputparameters
% t: dicrete time points
% p: solution for p at time points
% q: solution for q at time points

% Time intervall
% number of time steps
N = ceil(diff(tspan)/h);
h = diff(tspan)/N;
t = linspace(tspan(1),tspan(2),N+1);

% memory allocation
p = zeros(1,N+1); p(1) = p0;
q = zeros(1,N+1); q(1) = q0;

% system function for x = [p;q]
f = @(x) (x./(x(1)^2 + x(2)^2));

x = [p(1);q(1)];
for k = 2:length(t)
  k1 = f(x);
  k2 = f(x + h/2*k1);
  k3 = f(x + h/2*k2);
  k4 = f(x + h*k3);
  
  x = x + h/6*(k1 + 2*k2 + 2*k3 + k4);
  p(k) = x(1);
  q(k) = x(2);
end
