% script for convergence studies 

% allocate memory
kmax = 7;
h = (1/2).^(1:kmax);
N = length(h);
err_rk = zeros(1,N);
err_se = zeros(1,N);

% stop time
T = 1;

% initial data
p0 = 3;
q0 = 4;

% exact solution
p_ex = sqrt(2*T/(p0^2+q0^2)+1)*p0;
q_ex = sqrt(2*T/(p0^2+q0^2)+1)*q0;

for k = 1:N
  [t, prk, qrk] = RK4(p0, q0, [0 T], h(k));
  err_rk(k) = sqrt((prk(end) - p_ex)^2 + (qrk(end) - q_ex)^2);
  
  [t, pse, qse] = SympEuler(p0, q0, [0 T], h(k));
  err_se(k) = sqrt((pse(end) - p_ex)^2 + (qse(end) - q_ex)^2);
end

figure(1)
loglog(h,err_rk,'r*-', h, h.^4/10^10, 'k-.',h, err_se, 'b+-', h, h, 'k:')
grid on
legend('Runge-Kutta', 'Order 4', 'Symplectic Euler', 'Order 1',...
       'Location','SouthEast')
print -depsc 'errorRate.eps'

% find convergence rate
p=polyfit(log(h),log(err_se),1);
fprintf('Convergence rate of SympEuler = %2.4f\n',p(1));
p=polyfit(log(h(1:end-2)),log(err_rk(1:end-2)),1);
fprintf('Convergence rate of RK4 = %2.4f\n',p(1));
